@@ -33,17 +33,22 @@
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
 #include "panel-menu-bar.h"
-#include "panel-separator.h"
 #include "panel-multiscreen.h"
 #include "panel-toplevel.h"
 #include "panel-menu-button.h"
-#include "panel-globals.h"
 #include "panel-lockdown.h"
 #include "panel-icon-names.h"
 #include "panel-layout.h"
 #include "panel-schemas.h"
 #include "panel-user-menu.h"
 
+typedef struct _PanelData PanelData;
+struct _PanelData {
+	GtkWidget *panel;
+	GtkWidget *menu;
+	guint deactivate_idle;
+};
+
 enum {
 	TARGET_URL,
 	TARGET_NETSCAPE_URL,
@@ -81,10 +86,6 @@ orientation_change (AppletInfo  *info,
 	case PANEL_OBJECT_USER_MENU:
 		panel_menu_bar_object_set_orientation (PANEL_MENU_BAR_OBJECT (info->widget), orientation);
 		break;
-	case PANEL_OBJECT_SEPARATOR:
-		panel_separator_set_orientation (PANEL_SEPARATOR (info->widget),
-						 orientation);
-		break;
 	default:
 		break;
 	}
@@ -108,56 +109,6 @@ panel_orient_change (GtkWidget *widget, gpointer data)
 			      widget);
 }
 
-void
-back_change (AppletInfo  *info,
-	     PanelWidget *panel)
-{
-	PanelAppletFrame    *frame;
-	PanelBackgroundType  type;
-
-	switch (info->type) {
-	case PANEL_OBJECT_APPLET:
-		frame = PANEL_APPLET_FRAME (info->widget);
-		type = panel->toplevel->background.type;
-
-		PANEL_APPLET_FRAME_GET_CLASS (frame)->change_background (frame, type);
-		break;
-	case PANEL_OBJECT_ACTION:
-	case PANEL_OBJECT_LAUNCHER:
-	case PANEL_OBJECT_MENU:
-	case PANEL_OBJECT_MENU_BAR:
-	case PANEL_OBJECT_USER_MENU:
-	case PANEL_OBJECT_SEPARATOR:
-		break;
-	default:
-		break;
-	}
-}
-
-static void
-back_change_foreach (GtkWidget   *widget,
-		     PanelWidget *panel)
-{
-	AppletInfo *info;
-
-	info = g_object_get_data (G_OBJECT (widget), "applet_info");
-
-	back_change (info, panel);
-}
-
-static void
-panel_back_change (GtkWidget *widget, gpointer data)
-{
-	gtk_container_foreach (GTK_CONTAINER (widget),
-			       (GtkCallback) back_change_foreach,
-			       widget);
-
-#ifdef FIXME_FOR_NEW_CONFIG
-	/*update the configuration box if it is displayed*/
-	update_config_back(PANEL_WIDGET(widget));
-#endif /* FIXME_FOR_NEW_CONFIG */
-}
-
 static void
 panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 {
@@ -166,7 +117,6 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	info = g_object_get_data (G_OBJECT (applet), "applet_info");
 
 	orientation_change(info,PANEL_WIDGET(widget));
-	back_change(info,PANEL_WIDGET(widget));
 }
 
 static gboolean
@@ -175,8 +125,6 @@ deactivate_idle (gpointer data)
 	PanelData *pd = data;
 	pd->deactivate_idle = 0;
 
-	pd->insert_pack_type = PANEL_OBJECT_PACK_START;
-
 	return FALSE;
 }
 
@@ -216,8 +164,6 @@ panel_destroy (PanelToplevel *toplevel,
 	pd->deactivate_idle = 0;
 
 	g_object_set_data (G_OBJECT (toplevel), "PanelData", NULL);
-
-	panel_list = g_slist_remove (panel_list, pd);
 	g_free (pd);
 }
 
@@ -282,18 +228,10 @@ make_popup_panel_menu (PanelWidget *panel_widget)
 	PanelData *pd;
 	GtkWidget *menu;
 
-	if (!panel_widget) {
-		PanelToplevel *toplevel;
-
-		toplevel = PANEL_TOPLEVEL (((PanelData *) panel_list->data)->panel);
-
-		panel_widget = panel_toplevel_get_panel_widget (toplevel);
-	}
+	g_assert (panel_widget != NULL);
 
 	pd = g_object_get_data (G_OBJECT (panel_widget->toplevel), "PanelData");
 	menu = panel_menu_get (panel_widget, pd);
-	if (menu)
-		g_object_set_data (G_OBJECT (menu), "menu_panel", panel_widget);
 
 	return menu;
 }
@@ -305,22 +243,8 @@ panel_popup_menu (PanelToplevel *toplevel,
 {
 	PanelWidget *panel_widget;
 	GtkWidget   *menu;
-	PanelData   *panel_data;
-	GdkEvent    *current_event;
 
 	panel_widget = panel_toplevel_get_panel_widget (toplevel);
-	panel_data   = g_object_get_data (G_OBJECT (toplevel), "PanelData");
-
-	current_event = gtk_get_current_event ();
-	if (!current_event)
-		return FALSE;
-
-	if (current_event->type == GDK_BUTTON_PRESS)
-		panel_data->insert_pack_type = panel_widget_get_insert_pack_type_at_cursor (panel_widget);
-	else
-		panel_data->insert_pack_type = PANEL_OBJECT_PACK_START;
-
-	gdk_event_free (current_event);
 
 	menu = make_popup_panel_menu (panel_widget);
 	if (!menu)
@@ -371,22 +295,21 @@ panel_key_press_event (PanelToplevel *toplevel,
 }
 
 static GSettings *
-get_settings_background_for_toplevel (PanelToplevel *toplevel)
+get_theme_settings_for_toplevel (PanelToplevel *toplevel)
 {
 	char      *toplevel_settings_path;
 	GSettings *settings;
-	GSettings *settings_background;
+	GSettings *theme;
 
 	g_object_get (toplevel, "settings-path", &toplevel_settings_path, NULL);
 	settings = g_settings_new_with_path (PANEL_TOPLEVEL_SCHEMA,
 					     toplevel_settings_path);
-	settings_background = g_settings_get_child (settings,
-						    PANEL_BACKGROUND_SCHEMA_CHILD);
+	theme = g_settings_get_child (settings, "theme");
 
 	g_object_unref (settings);
 	g_free (toplevel_settings_path);
 
-	return settings_background;
+	return theme;
 }
 
 static gboolean
@@ -403,21 +326,18 @@ set_background_image_from_uri (PanelToplevel *toplevel,
 	}
 	g_object_unref (file);
 
-	settings = get_settings_background_for_toplevel (toplevel);
+	settings = get_theme_settings_for_toplevel (toplevel);
 
-	if (!g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_TYPE_KEY) ||
-	    !g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_IMAGE_URI_KEY)) {
+	if (!g_settings_is_writable (settings, "custom-bg-image") ||
+	    !g_settings_is_writable (settings, "bg-image")) {
 		g_object_unref (settings);
 		return FALSE;
 	}
 
-	g_settings_set_string (settings, PANEL_BACKGROUND_IMAGE_URI_KEY, uri);
-	g_settings_set_enum (settings, PANEL_BACKGROUND_TYPE_KEY, PANEL_BACK_IMAGE);
+	g_settings_set_enum (settings, "custom-bg-image", TRUE);
+	g_settings_set_string (settings, "bg-image", uri);
 
 	g_object_unref (settings);
-
 	return FALSE;
 }
 
@@ -432,12 +352,10 @@ set_background_color (PanelToplevel *toplevel,
 	if (!dropped)
 		return FALSE;
 
-	settings = get_settings_background_for_toplevel (toplevel);
+	settings = get_theme_settings_for_toplevel (toplevel);
 
-	if (!g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_TYPE_KEY) ||
-	    !g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_COLOR_KEY)) {
+	if (!g_settings_is_writable (settings, "custom-bg-color") ||
+	    !g_settings_is_writable (settings, "bg-color")) {
 		g_object_unref (settings);
 		return FALSE;
 	}
@@ -449,12 +367,11 @@ set_background_color (PanelToplevel *toplevel,
 
 	color_str = gdk_rgba_to_string (&color);
 
-	g_settings_set_string (settings, PANEL_BACKGROUND_COLOR_KEY, color_str);
-	g_settings_set_enum (settings, PANEL_BACKGROUND_TYPE_KEY, PANEL_BACK_COLOR);
-
+	g_settings_set_boolean (settings, "custom-bg-color", TRUE);
+	g_settings_set_string (settings, "bg-color", color_str);
 	g_free (color_str);
-	g_object_unref (settings);
 
+	g_object_unref (settings);
 	return TRUE;
 }
 
@@ -463,16 +380,14 @@ reset_background (PanelToplevel *toplevel)
 {
 	GSettings *settings;
 
-	settings = get_settings_background_for_toplevel (toplevel);
+	settings = get_theme_settings_for_toplevel (toplevel);
 
-	if (!g_settings_is_writable (settings,
-				     PANEL_BACKGROUND_TYPE_KEY)) {
+	if (!g_settings_is_writable (settings, "custom-bg-image")) {
 		g_object_unref (settings);
 		return FALSE;
 	}
 
-	g_settings_set_enum (settings, PANEL_BACKGROUND_TYPE_KEY, PANEL_BACK_NONE);
-
+	g_settings_set_boolean (settings, "custom-bg-image", FALSE);
 	g_object_unref (settings);
 
 	return TRUE;
@@ -928,15 +843,6 @@ drop_internal_applet (PanelWidget         *panel,
 			success = FALSE;
 		}
 
-	} else if (!strcmp(applet_type,"SEPARATOR:NEW")) {
-		if (panel_layout_is_writable ()) {
-			panel_separator_create (panel->toplevel,
-						pack_type, pack_index);
-			success = TRUE;
-		} else {
-			success = FALSE;
-		}
-
 	} else if (!strcmp (applet_type, "USERMENU:NEW")) {
 		if (panel_layout_is_writable ()) {
 			panel_user_menu_create (panel->toplevel,
@@ -1267,30 +1173,23 @@ panel_widget_setup(PanelWidget *panel)
 			  "applet_move",
 			  G_CALLBACK(panel_applet_move),
 			  NULL);
-	g_signal_connect (G_OBJECT (panel),
-			  "back_change",
-			  G_CALLBACK (panel_back_change),
-			  NULL);
 }
 
-PanelData *
+void
 panel_setup (PanelToplevel *toplevel)
 {
 	PanelWidget *panel_widget;
 	PanelData   *pd;
 
-	g_return_val_if_fail (PANEL_IS_TOPLEVEL (toplevel), NULL);
+	g_return_if_fail (PANEL_IS_TOPLEVEL (toplevel));
 
 	panel_widget = panel_toplevel_get_panel_widget (toplevel);
 
 	pd = g_new0 (PanelData,1);
 	pd->menu = NULL;
 	pd->panel = GTK_WIDGET (toplevel);
-	pd->insert_pack_type = PANEL_OBJECT_PACK_START;
 	pd->deactivate_idle = 0;
 
-	panel_list = g_slist_append (panel_list, pd);
-	
 	g_object_set_data (G_OBJECT (toplevel), "PanelData", pd);
 
 	panel_widget_setup (panel_widget);
@@ -1315,8 +1214,6 @@ panel_setup (PanelToplevel *toplevel)
 				  G_CALLBACK (panel_orient_change), panel_widget);
  
 	g_signal_connect (toplevel, "destroy", G_CALLBACK (panel_destroy), pd);
-
-	return pd;
 }
 
 GdkScreen *
